@@ -1,21 +1,8 @@
-// GUI_Export - Export interface of MediaInfo
-// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This program is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this program. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 #ifndef GUI_ExportH
@@ -66,12 +53,12 @@ __published:    // IDE-managed Components
     TComboBox *CSV_Stream_Audio;
     TLabel *CSV_Stream_Text_Caption;
     TComboBox *CSV_Stream_Text;
-    TLabel *CSV_Stream_Chapters_Caption;
-    TComboBox *CSV_Stream_Chapters;
+    TLabel *CSV_Stream_Other_Caption;
+    TComboBox *CSV_Stream_Other;
     TLabel *CSV_Stream_Video_Warning;
     TLabel *CSV_Stream_Audio_Warning;
     TLabel *CSV_Stream_Text_Warning;
-    TLabel *CSV_Stream_Chapters_Warning;
+    TLabel *CSV_Stream_Other_Warning;
     TCheckBox *Text_Advanced;
     TCheckBox *HTML_Advanced;
     TLabel *CSV_Quote_Caption;
@@ -103,7 +90,7 @@ __published:    // IDE-managed Components
     void __fastcall CSV_Stream_VideoChange(TObject *Sender);
     void __fastcall CSV_Stream_AudioChange(TObject *Sender);
     void __fastcall CSV_Stream_TextChange(TObject *Sender);
-    void __fastcall CSV_Stream_ChaptersChange(TObject *Sender);
+    void __fastcall CSV_Stream_OtherChange(TObject *Sender);
     void __fastcall Export_reVTMD_SideCarClick(TObject *Sender);
     void __fastcall Export_XML_SideCarClick(TObject *Sender);
     void __fastcall Export_MPEG7_SideCarClick(TObject *Sender);
